Learn R Programming

IIS (version 1.0)

agricultural_chargeoff_rates_by_quarter: Agricultural Chargeoff Rates by Quarter

Description

This data set contains twenty-five years (1991 through 2015) of quarterly charge-off rates for agricultural loans as reported by the Federal Reserve. This is the full dataset corresponding to the selected rows displayed in Table 2.5 of Wolfe and Schneider - Intuitive Introductory Statistics.

Usage

agricultural_chargeoff_rates_by_quarter

Arguments

Format

A data.frame with 100 rows and 3 columns indicating the chargeoff rates for agricultural loans for each quarter.

Examples

Run this code
# NOT RUN {
data(agricultural_chargeoff_rates_by_quarter)
summary(agricultural_chargeoff_rates_by_quarter)
# }

Run the code above in your browser using DataLab