Learn R Programming

IIS (version 1.0)

body_temperature_and_heart_rate: Body Temperature and Heart Rate

Description

This data set contains body temperature values artificially generated by Shoemaker (1996), to closely recreate the original data obtained by Mackowiak et al. (1992) for 65 male and 65 female subjects.

Usage

body_temperature_and_heart_rate

Arguments

Format

A data.frame with 130 rows and 3 columns corresponding to the body temperature, gender (1 for male, 2 for female), and heart rate for each subject.

Examples

Run this code
# NOT RUN {
data(body_temperature_and_heart_rate)
summary(body_temperature_and_heart_rate)
# }

Run the code above in your browser using DataLab