Learn R Programming

IIS (version 1.0)

delinquency_rates: Delinquency Rates

Description

This data set contains twenty-five years (1991 through 2015) of quarterly delinquency rates for eight different types of loans as reported by the Federal Reserve.

Usage

delinquency_rates

Arguments

Format

A data.frame with 100 rows and 9 columns indicating the delinquency rates for each of the eight loan types for each quarter.

Examples

Run this code
# NOT RUN {
data(delinquency_rates)
summary(delinquency_rates)
# }

Run the code above in your browser using DataLab