Learn R Programming

IIS (version 1.0)

desimipramine: Desimipramine

Description

This data set contains the body weight of 12 subjects with anorexia nervosa before and after treatment with the medication desimipramine as reported by Brambilla et al. (1985). This data is displayed in Table 8.3 of Wolfe and Schneider - Intuitive Introductory Statistics.

Usage

desimipramine

Arguments

Format

A data.frame with 12 rows and 2 columns indicating the pre-treatment and post-treatment weights (in kg) of each subject.

Examples

Run this code
# NOT RUN {
data(desimipramine)
summary(desimipramine)
# }

Run the code above in your browser using DataLab