Learn R Programming

IIS (version 1.0)

diamonds_carats_color_cost: Diamonds Carats Color Cost

Description

This data set contains weight in carats, color purity, grade of clarity, certification body, and value in Singapore dollars for 308 round diamond stones from an advertisement in the February 18, 2000 edition of Singapore's Business Times as discussed in Chu (2001).

Usage

diamonds_carats_color_cost

Arguments

Format

A data.frame with 308 rows and 5 columns indicating the attributes of each diamond.

Examples

Run this code
# NOT RUN {
data(diamonds_carats_color_cost)
summary(diamonds_carats_color_cost)
# }

Run the code above in your browser using DataLab