Learn R Programming

IIS (version 1.0)

fmr_white_tailed_deer: FMR White-Tailed Deer

Description

This data set contains data on the fasting metabolic rate (FMR) of white-tailed deer for different two-month periods of the year. This data is displayed in Table 12.9 of Wolfe and Schneider - Intuitive Introductory Statistics.

Usage

fmr_white_tailed_deer

Arguments

Format

A list with 3 vectors, each containing FMR (kcal/kg/day) for the deer observed in the corresponding time period.

Examples

Run this code
# NOT RUN {
data(fmr_white_tailed_deer)
summary(fmr_white_tailed_deer)
# }

Run the code above in your browser using DataLab