Learn R Programming

IIS (version 1.0)

gender_roles: Gender Roles

Description

This data set contains counts of gender 7685 individuals for which gender could be identified into the seven role categories. This data was used by Vigorito and Curry (1998) to investigate whether there is any relationship between gender and the roles that individuals play in magazine ad illustrations. This data is displayed in Table 10.12 of Wolfe and Schneider - Intuitive Introductory Statistics.

Usage

gender_roles

Arguments

Format

A data.frame with 7 rows and 2 columns indicating the counts for each gender and role category.

Examples

Run this code
# NOT RUN {
data(gender_roles)
summary(gender_roles)
# }

Run the code above in your browser using DataLab