Learn R Programming

IIS (version 1.0)

goggled_green_turtles: Goggled Green Turtles

Description

This data set contains the number of times that 36 turtle hatchlings split into two groups 'circled', in an attempt to determine whether light had an effect on the orientation and sea-finding ability of such hatchlings as reported by Mrosovsky and Shettleworth (1974). This data is displayed in Table 9.6 of Wolfe and Schneider - Intuitive Introductory Statistics.

Usage

goggled_green_turtles

Arguments

Format

A data.frame with 18 rows and 2 columns indicating the number of circles in a two-minute period for the nasal field goggles and for the harlequin goggles.

Examples

Run this code
# NOT RUN {
data(goggled_green_turtles)
summary(goggled_green_turtles)
# }

Run the code above in your browser using DataLab