Learn R Programming

IIS (version 1.0)

health_care_by_affiliation: Health Care by Affiliation

Description

This data set contains counts of respondents' preferences between two statements about healthcare grouped by political party from the report "Generation to Generation: American Values about Taking Care of Each Other" (1998). This data is displayed in Table 10.20 of Wolfe and Schneider - Intuitive Introductory Statistics.

Usage

health_care_by_affiliation

Arguments

Format

A data.frame with 2 rows and 2 columns indicating the counts for each statement and each party.

Examples

Run this code
# NOT RUN {
data(health_care_by_affiliation)
summary(health_care_by_affiliation)
# }

Run the code above in your browser using DataLab