Learn R Programming

IIS (version 1.0)

homes_prices: Homes Prices

Description

This data set contains the information about house prices for a random sample of 100 properties in Wake County, North Carolina, as collected by Woodard and Leone (2008).

Usage

homes_prices

Arguments

Format

A data.frame with 100 rows and 6 columns indicating the attributes of each house.

Examples

Run this code
# NOT RUN {
data(homes_prices)
summary(homes_prices)
# }

Run the code above in your browser using DataLab