Learn R Programming

IIS (version 1.0)

house_lot_sizes: House Lot Sizes

Description

This data set contains the information about house and lot sizes for a random sample of 100 properties in Wake County, North Carolina, as collected by Woodard and Leone (2008).

Usage

house_lot_sizes

Arguments

Format

A data.frame with 100 rows and 8 columns indicating the attributes of each house.

Examples

Run this code
# NOT RUN {
data(house_lot_sizes)
summary(house_lot_sizes)
# }

Run the code above in your browser using DataLab