Learn R Programming

IIS (version 1.0)

mother_smoking_age: Mother Smoking Age

Description

This data set contains the percentages of mothers in the United States who smoked during pregnancies from 2010 to 2014 for various age categories. This data is displayed in Table 2.14 of Wolfe and Schneider - Intuitive Introductory Statistics.

Usage

mother_smoking_age

Arguments

Format

A data.frame with 45 rows and 4 columns indicating the age group, number of births, and percentage of smoking mothers for each year.

Examples

Run this code
# NOT RUN {
data(mother_smoking_age)
summary(mother_smoking_age)
# }

Run the code above in your browser using DataLab