Learn R Programming

IIS (version 1.0)

mother_smoking_education: Mother Smoking Education

Description

This data set contains the percentages of mothers in the United States from 2010 to 2014 who smoked during pregnancy for various categories of educational level. A subset of this data is displayed in Table 2.13 of Wolfe and Schneider - Intuitive Introductory Statistics.

Usage

mother_smoking_education

Arguments

Format

A data.frame with 40 rows and 4 columns indicating the education, births, and percentage of smoking mothers for each year.

Examples

Run this code
# NOT RUN {
data(mother_smoking_education)
summary(mother_smoking_education)
# }

Run the code above in your browser using DataLab