Learn R Programming

IIS (version 1.0)

mother_smoking_education_1989_1993: Mother Smoking Education 1989-1993

Description

This data set contains the percentages of mothers in the United States from 1989 to 1993 who smoked during pregnancy for various categories of educational level. This data is displayed in Table 2.15 of Wolfe and Schneider - Intuitive Introductory Statistics.

Usage

mother_smoking_education_1989_1993

Arguments

Format

A data.frame with 25 rows and 3 columns indicating the education and percentage of smoking mothers for each year.

Examples

Run this code
# NOT RUN {
data(mother_smoking_education_1989_1993)
summary(mother_smoking_education_1989_1993)
# }

Run the code above in your browser using DataLab