Learn R Programming

IIS (version 1.0)

mother_smoking_education_2010: Mother Smoking Education 2010

Description

This data set contains the percentages of mothers in the United States in 2010 who smoked during pregnancy for various categories of educational level. This is a subset of the mother_smoking_education dataset.

Usage

mother_smoking_education_2010

Arguments

Format

A data.frame with 8 rows and 2 columns indicating the percentage of smoking mothers for each educational level in the year 2010.

Examples

Run this code
# NOT RUN {
data(mother_smoking_education_2010)
summary(mother_smoking_education_2010)
# }

Run the code above in your browser using DataLab