Learn R Programming

IIS (version 1.0)

percentage_hatched_eggs: Percentage Hatched Eggs

Description

This data set contains the percentages of eggs that eventually hatched for dump (communal) nests and normal nests each year from 1966 through 1974 as reported by Clawson et al. (1979). This data is displayed in Table 8.1 of Wolfe and Schneider - Intuitive Introductory Statistics.

Usage

percentage_hatched_eggs

Arguments

Format

A data.frame with 9 rows and 2 columns indicating the percentage of hatched eggs for the two nest types for each year.

Examples

Run this code
# NOT RUN {
data(percentage_hatched_eggs)
summary(percentage_hatched_eggs)
# }

Run the code above in your browser using DataLab