Learn R Programming

IIS (version 1.0)

pew_science_survey_data_by_age_group: Pew Science Survey Data By Age Group

Description

This data set contains the percentages of people who answered "yes" to various questions about scientific topics in a survey conducted by the Pew Research Center grouped by age group. This data is displayed in Table 2.18 of Wolfe and Schneider - Intuitive Introductory Statistics.

Usage

pew_science_survey_data_by_age_group

Arguments

Format

A data.frame with 5 rows and 4 columns indicating the proportion of respondents answering "yes" to each of the four questions indicated in Exercise 2.3.4. of Wolfe and Schneider - Intuitive Introductory Statistics by age group.

Examples

Run this code
# NOT RUN {
data(pew_science_survey_data_by_age_group)
summary(pew_science_survey_data_by_age_group)
# }

Run the code above in your browser using DataLab