Learn R Programming

IIS (version 1.0)

pew_science_survey_data_by_party: Pew Science Survey Data By Party

Description

This data set contains the percentages of people who answered "yes" to various questions about scientific topics in a survey conducted by the Pew Research Center grouped by political affiliation. This data is displayed in Table 2.17 of Wolfe and Schneider - Intuitive Introductory Statistics.

Usage

pew_science_survey_data_by_party

Arguments

Format

A data.frame with 3 rows and 4 columns indicating the proportion of respondents answering "yes" to each of the four questions indicated in Exercise 2.3.4. of Wolfe and Schneider - Intuitive Introductory Statistics by party.

Examples

Run this code
# NOT RUN {
data(pew_science_survey_data_by_party)
summary(pew_science_survey_data_by_party)
# }

Run the code above in your browser using DataLab