This data set contains the results of the final pre-election Gallup Voter Opinion Poll and the eventual election results for every presidential election from 1936 through 2012.
Usage
presidential_election_polls
Arguments
Format
A data.frame with 46 rows and 5 columns corresponding to the year, name, final polling estimate, actual election results, and deviation between polling and actual results for each candidate.