Learn R Programming

IIS (version 1.0)

proportion_for_profit_hospitals: Proportion For-Profit Hospitals

Description

This data set contains data on the proportion of a state's hospitals that are for-profit for a subset of states from each of four regions of the country. This data is displayed in Table 12.5 of Wolfe and Schneider - Intuitive Introductory Statistics.

Usage

proportion_for_profit_hospitals

Arguments

Format

A data.frame with 20 rows and 3 columns indicating the region and proportion of for-profit hospitals for each state.

Examples

Run this code
# NOT RUN {
data(proportion_for_profit_hospitals)
summary(proportion_for_profit_hospitals)
# }

Run the code above in your browser using DataLab