Learn R Programming

IIS (version 1.0)

reading_habits_2011: Reading Habits 2011

Description

This data set contains data from the 2011 Pew Research Center report titled "The Rise of E-reading" intended to investigate how reading and e-reading habits vary by demographic and socio-economic categories. A subset of this data is displayed in Table 3.4 of Wolfe and Schneider - Intuitive Introductory Statistics.

Usage

reading_habits_2011

Arguments

Format

A data.frame with 2986 rows and 7 columns indicating various pieces of demographic information and reading habits for each study participant.

Examples

Run this code
# NOT RUN {
data(reading_habits_2011)
summary(reading_habits_2011)
# }

Run the code above in your browser using DataLab