Learn R Programming

IIS (version 1.0)

school_report_cards_2014: School Report Cards 2014

Description

This data set contains 2014 school performance data, or "School Quality Snapshots", for high schools in New York City. A subset of this data is displayed in Table 3.2 of Wolfe and Schneider - Intuitive Introductory Statistics.

Usage

school_report_cards_2014

Arguments

Format

A data.frame with 484 rows and 8 columns indicating various performance statistics for each high school.

Examples

Run this code
# NOT RUN {
data(school_report_cards_2014)
summary(school_report_cards_2014)
# }

Run the code above in your browser using DataLab