state_poverty_levels_2013: State Poverty Levels 2013
Description
This data set contains the number of individuals in each state whose annual income was below the established poverty level in 2013 at a state-by-state level. This data is displayed in Table 1.4 of Wolfe and Schneider - Intuitive Introductory Statistics.
Usage
state_poverty_levels_2013
Arguments
Format
A data.frame with 50 rows and 3 columns corresponding to the name, total population, and number of people at or below the poverty line in each state.