Learn R Programming

IIS (version 1.0)

traffic_accidents: Traffic Accident Data

Description

This data set contains traffic accident data from 1949 and 1985 that is displayed in Table 1.2 of Wolfe and Schneider - Intuitive Introductory Statistics.

Usage

traffic_accidents

Arguments

Format

A data.frame with 9 rows and 2 columns. The rows correspond to various types of accidents and the two columns correspond to the years 1945 and 1985, respectively.

Examples

Run this code
# NOT RUN {
data(traffic_accidents)
summary(traffic_accidents)
# }

Run the code above in your browser using DataLab