Learn R Programming

IIS (version 1.0)

weekly_salaries: Weekly Salaries

Description

This data set contains the median weekly earnings of male and female employees in service occupations, sales and office occupations, and construction and extraction occupations for each quarter from 2005 to 2015. This data is displayed in Table 2.1 of Wolfe and Schneider - Intuitive Introductory Statistics.

Usage

weekly_salaries

Arguments

Format

A data.frame with 44 rows and 6 columns corresponding to male and female earnings for each of the three occupation types for each quarter.

Examples

Run this code
# NOT RUN {
data(weekly_salaries)
summary(weekly_salaries)
# }

Run the code above in your browser using DataLab