This data set contains twenty-five years (1991 through 2015) of quarterly charge-off rates for eight different types of loans as reported by the Federal Reserve. This data is displayed in Table 2.4 of Wolfe and Schneider - Intuitive Introductory Statistics.
Usage
chargeoff_rates
Arguments
Format
A data.frame with 100 rows and 9 columns indicating the chargeoff rates for each of the eight loan types for each quarter.