This data set contains a random sample of 100 movies from the 1996 edition of The Movie and Video Guide prepared annually by Leonard Maltin as selected by Moore (2006).
Usage
movie_facts
Arguments
Format
A data.frame with 100 rows and 6 columns corresponding to the title, release year, length (minutes), number of cast members, rating, and number of lines of description for each movie.