This data set contains traffic accident data from 1949 and 1985 that is displayed in Table 1.2 of Wolfe and Schneider - Intuitive Introductory Statistics.
Usage
traffic_accidents
Arguments
Format
A data.frame with 9 rows and 2 columns. The rows correspond to various types of accidents and the two columns correspond to the years 1945 and 1985, respectively.